==================================================
pytag -- Yet another tool to handle audio metadata
==================================================


pytag is a Python 3 library to handle audio metadata.


Documentation
-------------

Documentation for pytag is hosted at http://jlesquembre.github.io/pytag/


Status
------

.. image:: https://secure.travis-ci.org/jlesquembre/pytag.png?branch=master
    :target: http://travis-ci.org/jlesquembre/pytag

.. image:: https://coveralls.io/repos/jlesquembre/pytag/badge.png?branch=master
    :target: https://coveralls.io/r/jlesquembre/pytag?branch=master
    :alt: Coverage Status
